package
Version:
v0.0.0-...-631ac28
Opens a new window with list of versions in this module.
Published: Apr 7, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Coordinate struct {
X int
Y int
}
type RandomParameters interface {
GetNodeCount() int
GetMinimumDistance() int
GetMaximumPlotAttempts() int
GetGridSizeX() int
GetGridSizeY() int
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.